@@ -652,7 +652,7 @@ also added.")
           (:nxref :slot 'command-dispatcher :class-name 'window)
           " and " (:nxref :slot 'input-skip-dispatcher :class-name 'window) ".")
      (:li "Rename buffer slot " (:code "load-status") " to "
-          (:nxref :slot 'status :class-name 'buffer) ".")
+          (:nxref :slot 'status :class-name 'network-buffer) ".")
      (:li "The core " (:code "nyxt")
           " packages are now locked to prevent against accidental clobbering from the user
 side.")
@@ -693,3 +693,78 @@ JavaScript calls.")
           " attribute list is interpreted as display HTML for the suggestion. See the
 color-picker support as an example application for this feature.")
      (:li "New " (:nxref :function 'match-port) " URL designator predicate for auto-rules."))))
+
+(define-version "3.1.0"
+  (:ul
+   (:li "The REPL provides symbol suggestions by issuing "
+        (:nxref :command 'nyxt/mode/repl:suggest-into-cell) ", bound to "
+        (:code "TAB (↹)") ".")
+   (:li (:nxref :slot 'global-history-p :class-name 'buffer)
+        " is enabled by default.  The old behavior can be recovered by setting
+        it to " (:code "nil") ".")
+   (:li "Bind " (:nxref :command 'nyxt:delete-current-buffer) " uniformly for
+        all modes, when using the CUA keyscheme."))
+  (:h3 "Programming interfaces")
+  (:ul
+   (:li (:code "conservative-history-movement-p") " is deprecated in favor of "
+        (:nxref :slot 'global-history-p :class-name 'buffer) ".")))
+
+(define-version "3.2.0"
+  (:ul
+   (:li "Add support for PDF.js.")
+   (:li "Add command "
+        (:nxref :command 'nyxt/mode/prompt-buffer:toggle-suggestions-display)
+        ", that allows collapsing the prompt buffer to its input area.")
+   (:li "Improve the UI of the REPL.")
+   (:li "Output multiple values when evaluating Lisp expressions from "
+        (:nxref :command 'nyxt:execute-command) ".")
+   (:li "Bug fixes.")))
+
+(define-version "3.2.1"
+  (:ul
+   (:li "Fix clipboard support for the Flatpak.")))
+
+(define-version "3.3.0"
+  (:nsection :title "Features"
+  (:ul
+   (:li "Change default search engine to "
+        (:a :href "https://search.atlas.engineer/searxng"
+            "Atlas' own SearXNG instance") ".")
+   (:li "Add command " (:nxref :command 'nyxt:pick-color)
+        ", to pick a color and copy its HEX, RGB or HSL code to clipboard.")
+   (:li "Add keybindings for commands "
+        (:nxref :command 'nyxt:delete-panel-buffer) " and "
+        (:nxref :command 'nyxt:delete-all-panel-buffers) ".")
+   (:li "Improve " (:nxref :command 'nyxt/mode/prompt-buffer:describe-prompt-buffer) ":")
+   (:ul
+    (:li "List available keybindings for enabled prompt buffer modes.")
+    (:li "Reference current prompt buffer sources."))))
+  (:nsection :title "Bug fixes"
+  (:ul
+   (:li "Honor the value of "
+        (:nxref :slot 'zoom-ratio-default :class-name 'document-buffer) ".")
+   (:li "Honor the value of the panel buffer's "
+        (:nxref :slot 'style :class-name 'panel-buffer) ".")
+   (:li "Fix bugs in the "
+        (:a :href (nyxt-url 'common-settings) "common settings interface") ".")
+   (:li "Fix clipboard support for the Flatpak on Wayland.")
+   (:li "Fix behavior of "
+        (:nxref :class-name 'nyxt/mode/hint:hint-mode) "when slots "
+        (:nxref :class-name 'nyxt/mode/hint:hint-mode
+          :slot 'nyxt/mode/hint:hinting-type)
+        " and "
+        (:nxref :class-name 'nyxt/mode/hint:hint-mode
+          :slot 'nyxt/mode/hint:show-hint-scope-p)
+        "are set to " (:code ":vi") " and " (:code "t") ", respectively.")))
+  (:nsection :title "UI"
+    (:ul
+     (:li "Add border between panel buffer and main content area.")
+     (:li "Apply nuanced background color to panel buffers.")))
+  (:nsection :title "Programming interface"
+    (:ul
+
+     (:li (:nxref :class-name 'browser :slot 'external-editor-program)
+          " no longer signals when the program is a string containing spaces.")
+     (:li (:nxref :class-name 'browser :slot 'external-editor-program)
+          " returns its value rather than returning a string value in a list.")))
+  (:ul))
