@@ -193,12 +193,7 @@ shifts.  For instance if " (:code "C-x C-F") " fails to match anything " (:code
 documentation.  Bookmarks can also be used as search engines, see the
 corresponding section.")
         (:p "Nyxt comes with default search engines for "
-            (:code (format nil "~{~a~^, ~}"
-                           (mapcar (lambda (engine)
-                                     (quri:uri-host (quri:uri (getf engine :search-url))))
-                                   (rest (getf (mopu:slot-properties 'context-buffer 'search-engines)
-                                               :initform)))))
-            ". "
+            (:code "en.wikipedia.org, duckduckgo.com, search.atlas.engineer") ". "
             "The following example shows one way to add new search engines.")
         (:ncode
           '(defvar *my-search-engines*
@@ -256,10 +251,13 @@ commands like " (:nxref :command 'nyxt/mode/history:history-backwards) " and "
         (:p "If the beyond-buffer-boundaries behavior sounds like too much to you, or you
 prefer the behavior of Nyxt 2, where the history was still a tree, but was not
 spilling across the buffers, then configure "
-            (:nxref :slot 'nyxt/mode/history:conservative-history-movement-p
-              :class-name 'nyxt/mode/history:history-mode)
-            " to be T. This would make all buffers to have their own history, not connected
-to the other buffers at all. All the history commands (like "
+            (:nxref :slot 'global-history-p :class-name 'context-buffer)
+            " to be NIL:"
+            (:ncode
+              '(define-configuration :context-buffer
+                (global-history-p nil)))
+            " This would make all buffers to have their own history, not connected to the
+other buffers at all. All the history commands (like "
             (:nxref :command 'nyxt/mode/history:history-backwards) " and "
             (:nxref :command 'nyxt/mode/history:history-forwards)
             ") will only work inside the buffer history then.")
@@ -946,6 +944,8 @@ other cells.")
           (:ul
            (:li (:nxref :function 'nyxt/mode/repl:evaluate)
                 " as a function to get results from the cell.")
+           (:li (:nxref :function 'nyxt/mode/repl:suggest)
+                " for choosing the most intuitive content to paste into the cell.")
            (:li (:nxref :function 'nyxt/mode/repl:render-input)
                 " as the one rendering the input area for the cell.")
            (:li (:nxref :function 'nyxt/mode/repl:render-actions)
