@@ -185,15 +185,15 @@ In particular, we ignore the protocol (e.g. HTTP or HTTPS does not matter)."
     (panel-buffer "*Bookmarks panel*")
   "Shows all the bookmarks in a compact panel-buffer layout."
   (spinneret:with-html-string
-    (:nstyle (lass:compile-and-write
-              '(p
-                :font-size "12px"
-                :margin 0
-                :white-space nowrap
-                :overflow-x nidden
-                :text-overflow ellipsis)
-              '(div
-                :padding-bottom "10px")))
+    (:nstyle
+      '(p
+        :font-size "12px"
+        :margin 0
+        :white-space nowrap
+        :overflow-x hidden
+        :text-overflow ellipsis)
+      '(div
+        :padding-bottom "10px"))
     (:body
      (:h1 "Bookmarks")
      (or (let ((bookmarks (files:content (bookmarks-file (current-buffer)))))
